==> pointpos_api-0.0.16.tar.gz: test/ingredient_category_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for IngredientCategoryApi
void main() {
  var instance = new IngredientCategoryApi();

  group('tests for IngredientCategoryApi', () {
    // Create Ingredientcategory
    //
    // Create Ingredientcategory
    //
    //Future<IngredientCategory> createIngredientcategory(String authorization, String xAPIKey, IngredientCategory body, { String xPin }) async 
    test('test createIngredientcategory', () async {
      // TODO
    });

    // Delete Ingredientcategory By ID
    //
    // Delete Ingredientcategory By ID
    //
    //Future deleteIngredientcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test deleteIngredientcategoryByID', () async {
      // TODO
    });

    // Get Ingredientcategory List
    //
    // Get Ingredientcategory  List
    //
    //Future<List<IngredientCategory>> findIngredientcategory(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findIngredientcategory', () async {
      // TODO
    });

    // Get Ingredientcategory By ID
    //
    // Get Ingredientcategory By ID
    //
    //Future<IngredientCategory> getIngredientcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test getIngredientcategoryByID', () async {
      // TODO
    });

    // Update Ingredientcategory By ID
    //
    // Update [object Object] By ID
    //
    //Future<IngredientCategory> updateIngredientcategoryByID(String authorization, String xAPIKey, num id, IngredientCategory body, { String xPin }) async 
    test('test updateIngredientcategoryByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/ingredient_category_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for IngredientCategoryApi
void main() {
  var instance = new IngredientCategoryApi();

  group('tests for IngredientCategoryApi', () {
    // Create Ingredientcategory
    //
    // Create Ingredientcategory
    //
    //Future<IngredientCategory> createIngredientcategory(String authorization, String xAPIKey, IngredientCategory body, { String xPin }) async 
    test('test createIngredientcategory', () async {
      // TODO
    });

    // Delete Ingredientcategory By ID
    //
    // Delete Ingredientcategory By ID
    //
    //Future deleteIngredientcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test deleteIngredientcategoryByID', () async {
      // TODO
    });

    // Get Ingredientcategory List
    //
    // Get Ingredientcategory  List
    //
    //Future<List<IngredientCategory>> findIngredientcategory(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findIngredientcategory', () async {
      // TODO
    });

    // Get Ingredientcategory By ID
    //
    // Get Ingredientcategory By ID
    //
    //Future<IngredientCategory> getIngredientcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test getIngredientcategoryByID', () async {
      // TODO
    });

    // Update Ingredientcategory By ID
    //
    // Update [object Object] By ID
    //
    //Future<IngredientCategory> updateIngredientcategoryByID(String authorization, String xAPIKey, num id, IngredientCategory body, { String xPin }) async 
    test('test updateIngredientcategoryByID', () async {
      // TODO
    });

  });
}
